pub struct UnixListener { /* private fields */ }Expand description
A Unix socket which can accept connections from other Unix sockets.
You can accept a new connection by using the accept method. Alternatively UnixListener implements the Stream trait, which allows you to use the listener in places that want a stream. The stream will never return None and will also not yield the peer’s SocketAddr structure. Iterating over it is equivalent to calling accept in a loop.
Examples
use fd_queue::tokio::{UnixStream, UnixListener};
use futures_util::stream::StreamExt;
use tokio::io::{AsyncReadExt, AsyncWriteExt};
// let path: Path = ...
let mut listener = UnixListener::bind(&path)?;
tokio::spawn(async move {
let mut sock1 = UnixStream::connect(path).await?;
sock1.write(b"Hello World!").await?;
});
let mut sock2 = listener.next().await.expect("Listener stream unexpectedly empty")?;
let mut buf = [0u8; 256];
sock2.read(&mut buf).await?;
assert!(buf.starts_with(b"Hello World!"));Implementations
Sourceimpl UnixListener
impl UnixListener
Sourcepub fn bind(path: impl AsRef<Path>) -> Result<UnixListener>
pub fn bind(path: impl AsRef<Path>) -> Result<UnixListener>
Creates a new UnixListener bound to the specified path.
This function will bind a UnixListener to the specified path and associate it with the default event loop’s handler.
Panics
This function panics if thread-local runtime is not set.
The runtime is usually set implicitly when this function is called from a
future driven by a tokio runtime, otherwise runtime can be set explicitly
with Handle::enter function.
Examples
use fd_queue::tokio::UnixListener;
// let path: Path = ...
let listener = UnixListener::bind(&path)?;Sourcepub fn local_addr(&self) -> Result<SocketAddr>
pub fn local_addr(&self) -> Result<SocketAddr>
Returns the local socket address of this listener.
Examples
use fd_queue::tokio::UnixListener;
// let path: Path = ...
let listener = UnixListener::bind(&path)?;
let addr = listener.local_addr()?;
match addr.as_pathname() {
Some(path) => println!("The local address is {}.", path.display()),
None => println!("The local address does not have a pathname"),
}Sourcepub fn take_error(&self) -> Result<Option<Error>>
pub fn take_error(&self) -> Result<Option<Error>>
Returns the value of the SO_ERROR option.
Examples
use fd_queue::tokio::UnixListener;
// let path: Path = ...
let listener = UnixListener::bind(&path)?;
let so_error = listener.take_error()?;
match so_error {
Some(err) => println!("The SO_ERROR was {}.", err),
None => println!("There was no SO_ERROR."),
}Sourcepub async fn accept(&mut self) -> Result<(UnixStream, SocketAddr)>
pub async fn accept(&mut self) -> Result<(UnixStream, SocketAddr)>
Accepts a new incoming connection on this listener.
Panics
This function panics if thread-local runtime is not set.
The runtime is usually set implicitly when this function is called from a
future driven by a tokio runtime, otherwise runtime can be set explicitly
with Handle::enter function.
Examples
use fd_queue::tokio::UnixListener;
// let path: Path = ...
let mut listener = UnixListener::bind(&path)?;
let (sock, addr) = listener.accept().await?;Trait Implementations
Sourceimpl AsRawFd for UnixListener
impl AsRawFd for UnixListener
Sourceimpl Debug for UnixListener
impl Debug for UnixListener
Sourceimpl From<UnixListener> for UnixListener
impl From<UnixListener> for UnixListener
Sourcefn from(inner: TokioUnixListener) -> UnixListener
fn from(inner: TokioUnixListener) -> UnixListener
Sourceimpl Stream for UnixListener
Produces a continuous stream of accepted connections.
impl Stream for UnixListener
Produces a continuous stream of accepted connections.
This is the equivalent of calling accept() in a loop. It will never be ready
with None.
Panics
Polling the stream panics if thread-local runtime is not set.
The runtime is usually set implicitly when this function is called from a
future driven by a tokio runtime, otherwise runtime can be set explicitly
with Handle::enter function.
Examples
use fd_queue::tokio::UnixListener;
use futures_util::stream::StreamExt;
// let path: Path = ...
let mut listener = UnixListener::bind(&path)?;
let sock = listener.next().await.expect("Listener stream unexpectedly empty");Auto Trait Implementations
impl !Freeze for UnixListener
impl RefUnwindSafe for UnixListener
impl Send for UnixListener
impl Sync for UnixListener
impl Unpin for UnixListener
impl UnsafeUnpin for UnixListener
impl UnwindSafe for UnixListener