pub trait EnqueueFd {
// Required method
fn enqueue(&mut self, fd: &impl AsRawFd) -> Result<(), QueueFullError>;
}Expand description
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl EnqueueFd for fd_queue::mio::UnixStream
impl EnqueueFd for fd_queue::UnixStream
Enqueue a RawFd for later transmission across the UnixStream.
The RawFd will be transmitted on a later call to a method of Write.
The number of RawFd that can be enqueued before being transmitted is
bounded by FD_QUEUE_SIZE.